<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>WindowSelectionGrid</name>
    <message>
        <location filename="../qml/WindowSelectionGrid.qml" line="455"/>
        <source>No windows</source>
        <translation>Pencere yok</translation>
    </message>
</context>
<context>
    <name>WorkspaceSelectionList</name>
    <message>
        <location filename="../qml/WorkspaceSelectionList.qml" line="99"/>
        <source>Release to delete</source>
        <translation>Silmek için serbest bırak</translation>
    </message>
</context>
</TS>